@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 11376 2019-03-03 14:21:00Z Lavender $
+# $Id: create_zip.py 11438 2019-04-10 18:16:42Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-03-03 23:21:00 +0900 (週日, 03 三月 2019) $
-# $Revision: 11376 $
+# $Date: 2019-04-11 03:16:42 +0900 (週四, 11 四月 2019) $
+# $Revision: 11438 $
 
 import os
 import shutil
@@ -32,7 +32,7 @@ from django.template import Context
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH, 
     IMAGES_DIR_PATH, ROOT_DIR_PATH, FIXTURES_DIR_PATH)
-from Zephyrus.boilerplate.management.commands import createLogger
+from Zephyrus.boilerplate.management.commands import createLogger, toBytes
 from Zephyrus.boilerplate.management.commands import open3 as open
 from Zephyrus import ZEPHYRUS_VERSION
 from Iuppiter.Encoding import utf8
@@ -78,7 +78,7 @@ class Command(BaseCommand):
                         with open(os.path.join(root, temp), 'wb') as f:
                             f.write(utf8(htmlContent))
                         content += htmlContent
-                data['checksum'] = hashlib.md5(content).hexdigest()
+                data['checksum'] = hashlib.md5(toBytes(content)).hexdigest()
 
                 with open(os.path.join(ROOT_DIR_PATH, 'info.json'), 'w') as f:
                     line = json.dumps(data)
@@ -135,7 +135,7 @@ class Command(BaseCommand):
                 
             temp = get_template('boilerplate/txt/README.txt')
             content = temp.render()
-            with open(os.path.join(ROOT_DIR_PATH, 'README.txt'), 'w') as f:
+            with open(os.path.join(ROOT_DIR_PATH, 'README.txt'), 'wb') as f:
                 f.write(utf8(content))
 
             zip.write('./README.txt')
