@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 11461 2019-04-16 18:26:42Z Lavender $
+# $Id: pluginize.py 11671 2019-08-07 04:50:27Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-17 02:26:42 +0800 (週三, 17 四月 2019) $
-# $Revision: 11461 $
+# $Date: 2019-08-07 13:50:27 +0900 (週三, 07 八月 2019) $
+# $Revision: 11671 $
 
 import os
 import json
@@ -335,26 +335,42 @@ class Command(BaseCommand):
 
             @transaction.atomic
             def process():
-                for file in os.listdir(path):
-                    if options['template']:
-                        if not file == options['template']:
+                for root, dirs, files in os.walk(path):
+                    for file in files:
+                        if (path.endswith('/') or 
+                            path.endswith('\\')):
+                            templatePath = os.path.join(
+                                root.replace(path, ''), 
+                                file
+                            )
+                        else:
+                            # 去掉第一個 / or \
+                            templatePath = os.path.join(
+                                root.replace(path, '')[1:], 
+                                file
+                            )
+                        
+                        if options['template']:
+                            if not templatePath == options['template']:
+                                continue
+                        file = os.path.join(path, templatePath)
+                        
+                        result = os.path.splitext(file)[-1]
+                        if not result == ".html":
                             continue
-                    file = os.path.join(path, file)
-                    
-                    result = os.path.splitext(file)[-1]
-                    if not result == ".html":
-                        continue
+                            
+                        logger.info(file)
+                        
+                        f = open(file)
+                        t = template.Template(f.read())
+                        c = SekizaiContext()
+                        factory = RequestFactory()
+                        c['request'] = factory.get('/' + Placeholder2.lang + '/')
+                        c['request'].user = AnonymousUser()
+                        c['request'].current_page = Page.objects.get(pk=1)
+                        t.render(c)
+                        f.close()
                         
-                    logger.info(file)
-                    f = open(file)
-                    t = template.Template(f.read())
-                    c = SekizaiContext()
-                    factory = RequestFactory()
-                    c['request'] = factory.get('/' + Placeholder2.lang + '/')
-                    c['request'].user = AnonymousUser()
-                    c['request'].current_page = Page.objects.get(pk=1)
-                    t.render(c)
-                    f.close()
 
             process()
             
