@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11500 2019-04-30 18:49:58Z Lavender $
+# $Id: cms_plugins.py 11593 2019-05-29 06:23:49Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-01 03:49:58 +0900 (週三, 01 五月 2019) $
-# $Revision: 11500 $
+# $Date: 2019-05-29 15:23:49 +0900 (週三, 29 五月 2019) $
+# $Revision: 11593 $
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
@@ -41,7 +41,7 @@ class CMSCommentPlugin(CMSPluginBase):
         request = context['request']
         url = request.build_absolute_uri(request.path)
 
-        comments = Comment.objects.filter(url=url, display=True)
+        comments = Comment.objects.filter(url=url, display=True, facebook=False)
 
         obj, created = CommentConfig.objects.get_or_create(
             url=url,
