@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11660 2019-07-21 13:24:58Z Trista $
+# $Id: models.py 11661 2019-07-21 13:46:06Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2019-07-21 21:24:58 +0800 (週日, 21 七月 2019) $
-# $Revision: 11660 $
+# $Date: 2019-07-21 22:46:06 +0900 (週日, 21 七月 2019) $
+# $Revision: 11661 $
 
 
 from django.db import models
@@ -24,7 +24,7 @@ from django.core.validators import MaxValueValidator
 from cms.models import CMSPlugin
 
 # This might need to be adjusted to fit in any project
-from instagram import settings
+from Zephyrus.instagram import settings
 
 # Create your models here.
 
